@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/connectparticipant/ConnectParticipant_EXPORTS.h>
@@ -26,8 +16,15 @@ namespace Model
   enum class ChatItemType
   {
     NOT_SET,
+    TYPING,
+    PARTICIPANT_JOINED,
+    PARTICIPANT_LEFT,
+    CHAT_ENDED,
+    TRANSFER_SUCCEEDED,
+    TRANSFER_FAILED,
     MESSAGE,
     EVENT,
+    ATTACHMENT,
     CONNECTION_ACK
   };
 
