@@ -1,23 +1,15 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/organizations/Organizations_EXPORTS.h>
 #include <aws/organizations/OrganizationsRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/organizations/model/IAMUserAccessToBilling.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/organizations/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -162,8 +154,8 @@ namespace Model
     /**
      * <p>(Optional)</p> <p>The name of an IAM role that AWS Organizations
      * automatically preconfigures in the new member account. This role trusts the
-     * master account, allowing users in the master account to assume the role, as
-     * permitted by the master account administrator. The role has administrator
+     * management account, allowing users in the management account to assume the role,
+     * as permitted by the management account administrator. The role has administrator
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
@@ -184,8 +176,8 @@ namespace Model
     /**
      * <p>(Optional)</p> <p>The name of an IAM role that AWS Organizations
      * automatically preconfigures in the new member account. This role trusts the
-     * master account, allowing users in the master account to assume the role, as
-     * permitted by the master account administrator. The role has administrator
+     * management account, allowing users in the management account to assume the role,
+     * as permitted by the management account administrator. The role has administrator
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
@@ -206,8 +198,8 @@ namespace Model
     /**
      * <p>(Optional)</p> <p>The name of an IAM role that AWS Organizations
      * automatically preconfigures in the new member account. This role trusts the
-     * master account, allowing users in the master account to assume the role, as
-     * permitted by the master account administrator. The role has administrator
+     * management account, allowing users in the management account to assume the role,
+     * as permitted by the management account administrator. The role has administrator
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
@@ -228,8 +220,8 @@ namespace Model
     /**
      * <p>(Optional)</p> <p>The name of an IAM role that AWS Organizations
      * automatically preconfigures in the new member account. This role trusts the
-     * master account, allowing users in the master account to assume the role, as
-     * permitted by the master account administrator. The role has administrator
+     * management account, allowing users in the management account to assume the role,
+     * as permitted by the management account administrator. The role has administrator
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
@@ -250,8 +242,8 @@ namespace Model
     /**
      * <p>(Optional)</p> <p>The name of an IAM role that AWS Organizations
      * automatically preconfigures in the new member account. This role trusts the
-     * master account, allowing users in the master account to assume the role, as
-     * permitted by the master account administrator. The role has administrator
+     * management account, allowing users in the management account to assume the role,
+     * as permitted by the management account administrator. The role has administrator
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
@@ -272,8 +264,8 @@ namespace Model
     /**
      * <p>(Optional)</p> <p>The name of an IAM role that AWS Organizations
      * automatically preconfigures in the new member account. This role trusts the
-     * master account, allowing users in the master account to assume the role, as
-     * permitted by the master account administrator. The role has administrator
+     * management account, allowing users in the management account to assume the role,
+     * as permitted by the management account administrator. The role has administrator
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
@@ -294,8 +286,8 @@ namespace Model
     /**
      * <p>(Optional)</p> <p>The name of an IAM role that AWS Organizations
      * automatically preconfigures in the new member account. This role trusts the
-     * master account, allowing users in the master account to assume the role, as
-     * permitted by the master account administrator. The role has administrator
+     * management account, allowing users in the management account to assume the role,
+     * as permitted by the management account administrator. The role has administrator
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
@@ -316,8 +308,8 @@ namespace Model
     /**
      * <p>(Optional)</p> <p>The name of an IAM role that AWS Organizations
      * automatically preconfigures in the new member account. This role trusts the
-     * master account, allowing users in the master account to assume the role, as
-     * permitted by the master account administrator. The role has administrator
+     * management account, allowing users in the management account to assume the role,
+     * as permitted by the management account administrator. The role has administrator
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
@@ -414,6 +406,111 @@ namespace Model
      */
     inline CreateAccountRequest& WithIamUserAccessToBilling(IAMUserAccessToBilling&& value) { SetIamUserAccessToBilling(std::move(value)); return *this;}
 
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline CreateAccountRequest& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline CreateAccountRequest& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline CreateAccountRequest& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline CreateAccountRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_email;
@@ -427,6 +524,9 @@ namespace Model
 
     IAMUserAccessToBilling m_iamUserAccessToBilling;
     bool m_iamUserAccessToBillingHasBeenSet;
+
+    Aws::Vector<Tag> m_tags;
+    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
